@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -108,20 +108,24 @@ class CControllerAuthenticationUpdate extends CController {
 	private function validateLdap() {
 		$is_valid = true;
 		$ldap_status = (new CFrontendSetup())->checkPhpLdapModule();
-		$ldap_fields = ['ldap_host', 'ldap_port', 'ldap_base_dn', 'ldap_bind_dn', 'ldap_search_attribute',
-			'ldap_bind_password', 'ldap_configured'
-		];
+		$ldap_fields = ['ldap_host', 'ldap_port', 'ldap_base_dn', 'ldap_search_attribute', 'ldap_configured'];
 		$config = select_config();
-		$this->getInputs($config, $ldap_fields);
+		$this->getInputs($config, array_merge($ldap_fields, ['ldap_bind_dn', 'ldap_bind_password']));
 		$ldap_settings_changed = array_diff_assoc($config, select_config());
 
 		if (!$ldap_settings_changed && !$this->hasInput('ldap_test')) {
 			return $is_valid;
 		}
 
+		if ($this->getInput('ldap_bind_password', '') !== '') {
+			$ldap_fields[] = 'ldap_bind_dn';
+		}
+
 		foreach($ldap_fields as $field) {
 			if (trim($config[$field]) === '') {
-				$this->response->setMessageError(_s('Incorrect value for field "%1$s": cannot be empty.', $field));
+				$this->response->setMessageError(
+					_s('Incorrect value for field "%1$s": %2$s.', $field, _('cannot be empty'))
+				);
 				$is_valid = false;
 				break;
 			}
@@ -220,6 +224,10 @@ class CControllerAuthenticationUpdate extends CController {
 		$this->getInputs($data, array_keys($fields));
 		$data = array_diff_assoc($data, $config);
 
+		if (array_key_exists('ldap_bind_dn', $data) && trim($data['ldap_bind_dn']) === '') {
+			$data['ldap_bind_password'] = '';
+		}
+
 		if ($data) {
 			$result = update_config($data);
 
